summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--gnu/packages/audio.scm29
-rw-r--r--gnu/packages/lxde.scm169
2 files changed, 186 insertions, 12 deletions
diff --git a/gnu/packages/lxde.scm b/gnu/packages/lxde.scm
index 6d7580c1b2..fe71a17406 100644
--- a/gnu/packages/lxde.scm
+++ b/gnu/packages/lxde.scm
@@ -17,13 +17,56 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (gnu packages lxde)
+  #:use-module (gnu packages autotools)
   #:use-module (gnu packages glib)
+  #:use-module (gnu packages gnome)
   #:use-module (gnu packages gtk)
   #:use-module (gnu packages pkg-config)
+  #:use-module (gnu packages xorg)
   #:use-module (guix build-system gnu)
   #:use-module (guix download)
   #:use-module ((guix licenses) #:prefix license:)
-  #:use-module (guix packages))
+  #:use-module (guix packages)
+  #:use-module (guix utils))
+
+(define-public libfm
+  (package
+    (name "libfm")
+    (version "1.2.3")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://sourceforge/project/pcmanfm/"
+                                  "PCManFM%20%2B%20Libfm%20%28tarball%20release"
+                                  "%29/LibFM/" name "-" version ".tar.xz"))
+              (sha256
+               (base32
+                "1ygvw52262r3jp1f45m9cdpx5xgvd4rkyfszslfqvg2c99ig34n6"))))
+    (build-system gnu-build-system)
+    (inputs `(("glib" ,glib)
+              ("gtk+" ,gtk+-2)))
+    (native-inputs `(("intltool"   ,intltool)
+                     ("glib"       ,glib "bin") ; for gtester
+                     ("libtool"    ,libtool)
+                     ("menu-cache" ,menu-cache)
+                     ("pkg-config" ,pkg-config)
+                     ("vala"       ,vala)))
+    (synopsis "File management support (core library)")
+    (description "LibFM provides file management functions built on top of
+Glib/GIO giving a higher-level API.")
+    (home-page "http://lxde.org")
+    (license license:gpl2+)))
+
+(define-public libfm-extra
+  (package (inherit libfm)
+    (name "libfm-extra")
+    (arguments '(#:configure-flags '("--with-extra-only")))
+    (inputs `(("glib" ,glib)))
+    (native-inputs `(("intltool"   ,intltool)
+                     ("libtool"    ,libtool)
+                     ("pkg-config" ,pkg-config)))
+    (synopsis "File management support (extra library)")
+    (description "This package contains standalone library which extends the
+libFM file management library.")))
 
 (define-public lxappearance
   (package
@@ -46,4 +89,128 @@ able to change themes, icons, and fonts used by GTK+ applications.")
     (home-page "http://lxde.org")
     (license license:gpl2+)))
 
+(define-public lxrandr
+  (package
+    (name "lxrandr")
+    (version "0.3.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://sourceforge/project/lxde/LXRandR"
+                                  "%20%28monitor%20config%20tool%29/LXRandR%20"
+                                  (version-major+minor version) ".x/"
+                                  name "-" version ".tar.xz"))
+              (sha256
+               (base32
+                "0xkbqv66hisbxkvnf7y5kwqbhrq26f49wd7w6ylhnjlccpnylg8q"))))
+    (build-system gnu-build-system)
+    (inputs `(("gtk+" ,gtk+-2)))
+    (native-inputs `(("intltool"   ,intltool)
+                     ("pkg-config" ,pkg-config)))
+    (synopsis "LXDE monitor configuration tool")
+    (description "LXRandR is a very basic monitor configuration tool.  It
+relies on the X11 resize-and-rotate (RandR) extension but doesn't aim to be a
+full frontend of it.  LXRandR only gives you some easy and quick options which
+are intuitive.  It's suitable for laptop users who frequently uses projectors
+or external monitor.")
+    (home-page "http://lxde.org")
+    (license license:gpl2+)))
+
+(define-public lxtask
+  (package
+    (name "lxtask")
+    (version "0.1.6")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://sourceforge/project/lxde/LXTask"
+                                  "%20%28task%20manager%29/LXTask%20"
+                                  (version-major+minor version) ".x/"
+                                  name "-" version ".tar.xz"))
+              (sha256
+               (base32
+                "0ia3i430lpwgl2kch6sl1za8qf96wc4fkcv91yhdzgnzafcnm3gp"))))
+    (build-system gnu-build-system)
+    (inputs `(("gtk+" ,gtk+-2)))
+    (native-inputs `(("intltool"   ,intltool)
+                     ("pkg-config" ,pkg-config)))
+    (synopsis "LXDE task manager")
+    (description "LXTask is a lightweight task manager derived from Xfce task
+manager with all dependencies on Xfce removed.  LXTask is based on the GTK+
+toolkit.  It allows users to monitor and control of running processes.")
+    (home-page "http://lxde.org")
+    (license license:gpl2+)))
+
+(define-public lxterminal
+  (package
+    (name "lxterminal")
+    (version "0.2.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://sourceforge/project/lxde/LXTerminal"
+                                  "%20%28terminal%20emulator%29/LXTerminal%20"
+                                  version "/" name "-" version ".tar.gz"))
+              (sha256
+               (base32
+                "1brb506vmnncih8nyvlrckrrn6msbsvz2vwbm7bsqwigcnchwjqp"))))
+    (build-system gnu-build-system)
+    (inputs `(("gtk+" ,gtk+-2)
+              ("vte"  ,vte/gtk+-2)))
+    (native-inputs `(("intltool"   ,intltool)
+                     ("pkg-config" ,pkg-config)))
+    (synopsis "LXDE terminal emulator")
+    (description "LXTerminal is a VTE-based terminal emulator.  It supports
+multiple tabs and has only minimal dependencies thus being completely
+desktop-independent.  In order to reduce memory usage and increase the
+performance, all instances of the terminal are sharing a single process.")
+    (home-page "http://lxde.org")
+    (license license:gpl2+)))
+
+(define-public menu-cache
+  (package
+    (name "menu-cache")
+    (version "1.0.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://sourceforge/project/lxde/" name "/"
+                                  (version-major+minor version) "/"
+                                  name "-" version ".tar.xz"))
+              (sha256
+               (base32
+                "1bws84fiwk3anp30hcr0lw1xw5cgp44x5ik2yv2ijcgxpcvz8zgz"))))
+    (build-system gnu-build-system)
+    (inputs `(("glib"  ,glib)
+              ("libfm" ,libfm-extra)))
+    (native-inputs `(("pkg-config" ,pkg-config)))
+    (synopsis "LXDE implementation of the freedesktop menu's cache")
+    (description "Menu-cache is a library creating and utilizing caches to
+speed up the access to freedesktop.org defined application menus.")
+    (home-page "http://lxde.org")
+    (license license:lgpl2.1+)))
+
+(define-public pcmanfm
+  (package
+    (name "pcmanfm")
+    (version "1.2.3")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://sourceforge/project/" name "/"
+                                  "PCManFM%20%2B%20Libfm%20%28tarball%20release"
+                                  "%29/PCManFM/" name "-" version ".tar.xz"))
+              (sha256
+               (base32
+                "1033rw5jd7nlzbcdpx3bik7347kyh1sg1gkla424gq9vqqpxia6g"))))
+    (build-system gnu-build-system)
+    ;; (#:configure-flags '("--sysconfdir=/etc")) suggested in README.
+    (inputs `(("gtk+"   ,gtk+-2)
+              ;; TODO: add ("gvfs" ,gvfs).
+              ("libfm"  ,libfm)
+              ("libx11" ,libx11)))
+    (native-inputs `(("intltool"   ,intltool)
+                     ("libtool"    ,libtool)
+                     ("pkg-config" ,pkg-config)))
+    (synopsis "LXDE file manager")
+    (description "PCMan is a lightweight GTK+ based file manager, compliant
+with freedesktop.org standard.")
+    (home-page "http://lxde.org")
+    (license license:gpl2+)))
+
 ;;; lxde.scm ends here
diff --git a/gnu/packages/audio.scm b/gnu/packages/audio.scm
index 8b12b18973..388e4ea704 100644
--- a/gnu/packages/audio.scm
+++ b/gnu/packages/audio.scm
@@ -3,6 +3,7 @@
 ;;; Copyright © 2015 Taylan Ulrich Bayırlı/Kammer <taylanbayirli@gmail.com>
 ;;; Copyright © 2015 Andreas Enge <andreas@enge.fr>
 ;;; Copyright © 2015 Alex Kost <alezost@gmail.com>
+;;; Copyright © 2015 Mark H Weaver <mhw@netris.org>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -1374,17 +1375,23 @@ analysis plugins or audio feature extraction plugins.")
     (build-system gnu-build-system)
     (native-inputs `(("automake" ,automake)))
     (arguments
-     `(#:phases
-       (alist-cons-after
-        'unpack 'fix-ar-lib-path
-        (lambda* (#:key inputs #:allow-other-keys)
-          ;; Originally a symlink to '/usr/local/share/automake-1.12/ar-lib'.
-          (delete-file "ar-lib")
-          (symlink
-           (string-append (assoc-ref inputs "automake") "/share/automake-"
-                          ,(package-version automake) "/ar-lib")
-           "ar-lib"))
-        %standard-phases)))
+     `(#:configure-flags
+       ;; Disable the use of SSE unless on x86_64.
+       ,(if (not (string-prefix? "x86_64" (or (%current-target-system)
+                                              (%current-system))))
+            ''("--disable-sse")
+            ''())
+       #:phases
+       (modify-phases %standard-phases
+         (add-after
+          'unpack 'fix-ar-lib-path
+          (lambda* (#:key inputs #:allow-other-keys)
+            ;; Originally a symlink to '/usr/local/share/automake-1.12/ar-lib'.
+            (delete-file "ar-lib")
+            (symlink
+             (string-append (assoc-ref inputs "automake") "/share/automake-"
+                            ,(package-version automake) "/ar-lib")
+             "ar-lib"))))))
     (home-page "http://sbsms.sourceforge.net/")
     (synopsis "Library for time stretching and pitch scaling of audio")
     (description